import * as i0 from '@angular/core';
import { Component, EventEmitter, Directive, Input, Output, HostListener, NgModule } from '@angular/core';
import * as i2 from '@angular/common/http';
import { HttpEventType, HttpClientModule } from '@angular/common/http';
import * as i3 from '@angular/common';
import { CommonModule } from '@angular/common';

class ImageManagerComponent {
    constructor(trigger, http, cd) {
        this.trigger = trigger;
        this.http = http;
        this.cd = cd;
        this.upload = false;
        this.images$ = this.http.get(this.trigger.apiPaths.getImages);
        this.progress = 0;
        this.errorMsg = '';
    }
    getImages(tag = '') {
        this.images$ = this.http.get(this.trigger.apiPaths.getImages + tag);
    }
    onSelectFiles(e, thumb, tag) {
        if (!tag.value) {
            tag.value = e.target.files?.item(0)?.name.replace(/\..+$/, '');
            this.cd.markForCheck();
        }
        thumb.src = URL.createObjectURL(e.target.files[0]);
    }
    onSelectItem() {
        this.trigger.s3imgSelected.emit(this.selected);
        this.trigger.vc.clear();
    }
    onUpload(tag, file) {
        const fd = new FormData;
        fd.append('tag', tag);
        fd.append('file', file.files ? file.files[0] : '');
        this.http.post(this.trigger.apiPaths.upload, fd, { withCredentials: true, reportProgress: true, observe: 'events' }).subscribe({
            next: (e) => {
                switch (e.type) {
                    case HttpEventType.UploadProgress:
                        this.progress = e.total ? e.loaded / e.total * 100 : 0;
                        break;
                    case HttpEventType.Response:
                        this.progress = 0;
                        this.upload = false;
                        this.getImages();
                        this.errorMsg = '';
                }
                this.cd.markForCheck();
            },
            error: e => {
                this.errorMsg = e.error;
            }
        });
    }
    deleteImage(id) {
        this.http.delete(this.trigger.apiPaths.delete + '/' + id).subscribe({
            next: () => alert("Image deleted")
        });
    }
    full() {
        window.open(this.selected.url, '', 'popup');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.0.2", ngImport: i0, type: ImageManagerComponent, deps: [{ token: TriggerDirective }, { token: i2.HttpClient }, { token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.0.2", type: ImageManagerComponent, selector: "s3imgs-image-manager", ngImport: i0, template: "<div id=\"s3-main\">\n\n  <span class=\"tb\" [class.active]=\"!upload\" (click)=\"upload=false\">Images</span>\n  <span class=\"tb\" [class.active]=\"upload\" (click)=\"upload=true\">Upload New</span>\n\n  <div id=\"sec\">\n\n    <ng-container *ngIf=\"!upload\">\n\n      <input type=\"text\" #tag placeholder=\"Tag\">\n      <button type=\"button\" class=\"primary\" (click)=\"getImages(tag.value)\">Search</button><br>\n\n      <div *ngIf=\"images$ | async as images\">\n        <small>Number of Images: {{images.length}}</small>\n        <div id=\"list\">\n\n          <div id=\"left\">\n            <div *ngFor=\"let item of images\" (click)=\"selected=item\" [class.selected]=\"selected==item\">\n              <img [src]=\"item.thumbnailUrl\" width=\"185\" height=\"185\" loading=\"lazy\">\n            </div>\n          </div>\n\n          <aside *ngIf=\"selected\">\n            <div>\n              <div>{{selected.thumbnail}}</div>\n              <p>Original Size: <b>{{selected.size / 1024 | number: '1.0-2'}} </b>KB</p>\n              <p>Tag: <b>{{selected.tag}} </b></p>\n              <button type=\"button\" class=\"primary\" (click)=\"full()\">View Full Size</button>\n            </div>\n            <footer>\n              <button type=\"button\" (click)=\"selected=null\">Close</button>\n              <button type=\"button\" class=\"warn\" [disabled]=\"trigger.disableDelete\"\n                (click)=\"deleteImage(selected.id)\">Delete</button>\n              <button type=\"button\" class=\"primary\" (click)=\"onSelectItem()\">Select</button>\n            </footer>\n          </aside>\n        </div>\n      </div>\n    </ng-container>\n\n\n    <form *ngIf=\"upload\">\n      <input #tag type=\"text\" placeholder=\"Tag\" required>\n      <span>\n        {{errorMsg}}\n      </span>\n      <br>\n      <small>Tags will be used when searching for images</small>\n      <label>\n        <input type=\"file\" #file accept=\"image/*\" (change)=\"onSelectFiles($event, thumb, tag)\" required>\n        <b>\n          Choose or drag image here\n        </b>\n      </label>\n      <img src=\"\" width=\"150\" #thumb>\n      <footer>\n        <button type=\"button\" class=\"primary\" (click)=\"onUpload(tag.value, file)\">Upload</button>\n\n        <progress [value]=\"progress\" max=\"100\"></progress>\n\n      </footer>\n    </form>\n\n    <button type=\"button\" (click)=\"trigger.vc.clear()\">Close</button>\n  </div>\n</div>", styles: [":host{font-family:sans-serif;position:fixed;z-index:220;background:rgba(68,68,68,.7882352941);inset:0}#s3-main{margin:30px 50px}#s3-main .tb{display:inline-block;background-color:#d3d3d3;font-size:18px;padding:13px 26px;cursor:pointer}#s3-main .tb.active{background:white}#s3-main input{font-size:16px;padding:6px;margin:0 12px 0 0;border:1px solid gray;border-radius:5px}#s3-main button{padding:7px 20px;font-size:16px;border:none;border-radius:5px;cursor:pointer;margin:5px}#s3-main button.primary{background:#03a9f4;color:#fff}#s3-main button.warn{background:#f44336;color:#fff}#s3-main button[disabled]{pointer-events:none;opacity:.3}#s3-main #sec{background:white;padding:25px}#s3-main #list{display:flex;margin:20px 0 35px}#s3-main #list #left{display:flex;align-items:baseline;gap:25px;flex-wrap:wrap;height:55vh;overflow:auto;padding:4px;flex-grow:1}#s3-main #list #left div{cursor:pointer}#s3-main #list #left div.selected{outline:4px solid #00b0ff}#s3-main #list #left img{display:block;object-fit:cover}#s3-main #list aside{background:#e5e5e5;padding:20px 10px;display:flex;flex-direction:column;justify-content:space-between;border-radius:6px}#s3-main #list aside footer{display:flex;justify-content:space-between}#s3-main form{padding:17px;background:#f3f3f3;border-radius:9px;margin:47px;border:none}#s3-main form span{color:red}#s3-main form label{display:block;background:azure;border:2px dashed #03a9f4;position:relative;margin:20px 0}#s3-main form label input{height:180px;width:100%;opacity:0;cursor:grab}#s3-main form label b{position:absolute;top:40%;left:42%;display:flex;font-size:20px}#s3-main form form:invalid #upload{background-color:#aaa;pointer-events:none}#s3-main progress{width:100%;margin-top:15px}\n"], dependencies: [{ kind: "directive", type: i3.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i3.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "pipe", type: i3.AsyncPipe, name: "async" }, { kind: "pipe", type: i3.DecimalPipe, name: "number" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.0.2", ngImport: i0, type: ImageManagerComponent, decorators: [{
            type: Component,
            args: [{ selector: 's3imgs-image-manager', template: "<div id=\"s3-main\">\n\n  <span class=\"tb\" [class.active]=\"!upload\" (click)=\"upload=false\">Images</span>\n  <span class=\"tb\" [class.active]=\"upload\" (click)=\"upload=true\">Upload New</span>\n\n  <div id=\"sec\">\n\n    <ng-container *ngIf=\"!upload\">\n\n      <input type=\"text\" #tag placeholder=\"Tag\">\n      <button type=\"button\" class=\"primary\" (click)=\"getImages(tag.value)\">Search</button><br>\n\n      <div *ngIf=\"images$ | async as images\">\n        <small>Number of Images: {{images.length}}</small>\n        <div id=\"list\">\n\n          <div id=\"left\">\n            <div *ngFor=\"let item of images\" (click)=\"selected=item\" [class.selected]=\"selected==item\">\n              <img [src]=\"item.thumbnailUrl\" width=\"185\" height=\"185\" loading=\"lazy\">\n            </div>\n          </div>\n\n          <aside *ngIf=\"selected\">\n            <div>\n              <div>{{selected.thumbnail}}</div>\n              <p>Original Size: <b>{{selected.size / 1024 | number: '1.0-2'}} </b>KB</p>\n              <p>Tag: <b>{{selected.tag}} </b></p>\n              <button type=\"button\" class=\"primary\" (click)=\"full()\">View Full Size</button>\n            </div>\n            <footer>\n              <button type=\"button\" (click)=\"selected=null\">Close</button>\n              <button type=\"button\" class=\"warn\" [disabled]=\"trigger.disableDelete\"\n                (click)=\"deleteImage(selected.id)\">Delete</button>\n              <button type=\"button\" class=\"primary\" (click)=\"onSelectItem()\">Select</button>\n            </footer>\n          </aside>\n        </div>\n      </div>\n    </ng-container>\n\n\n    <form *ngIf=\"upload\">\n      <input #tag type=\"text\" placeholder=\"Tag\" required>\n      <span>\n        {{errorMsg}}\n      </span>\n      <br>\n      <small>Tags will be used when searching for images</small>\n      <label>\n        <input type=\"file\" #file accept=\"image/*\" (change)=\"onSelectFiles($event, thumb, tag)\" required>\n        <b>\n          Choose or drag image here\n        </b>\n      </label>\n      <img src=\"\" width=\"150\" #thumb>\n      <footer>\n        <button type=\"button\" class=\"primary\" (click)=\"onUpload(tag.value, file)\">Upload</button>\n\n        <progress [value]=\"progress\" max=\"100\"></progress>\n\n      </footer>\n    </form>\n\n    <button type=\"button\" (click)=\"trigger.vc.clear()\">Close</button>\n  </div>\n</div>", styles: [":host{font-family:sans-serif;position:fixed;z-index:220;background:rgba(68,68,68,.7882352941);inset:0}#s3-main{margin:30px 50px}#s3-main .tb{display:inline-block;background-color:#d3d3d3;font-size:18px;padding:13px 26px;cursor:pointer}#s3-main .tb.active{background:white}#s3-main input{font-size:16px;padding:6px;margin:0 12px 0 0;border:1px solid gray;border-radius:5px}#s3-main button{padding:7px 20px;font-size:16px;border:none;border-radius:5px;cursor:pointer;margin:5px}#s3-main button.primary{background:#03a9f4;color:#fff}#s3-main button.warn{background:#f44336;color:#fff}#s3-main button[disabled]{pointer-events:none;opacity:.3}#s3-main #sec{background:white;padding:25px}#s3-main #list{display:flex;margin:20px 0 35px}#s3-main #list #left{display:flex;align-items:baseline;gap:25px;flex-wrap:wrap;height:55vh;overflow:auto;padding:4px;flex-grow:1}#s3-main #list #left div{cursor:pointer}#s3-main #list #left div.selected{outline:4px solid #00b0ff}#s3-main #list #left img{display:block;object-fit:cover}#s3-main #list aside{background:#e5e5e5;padding:20px 10px;display:flex;flex-direction:column;justify-content:space-between;border-radius:6px}#s3-main #list aside footer{display:flex;justify-content:space-between}#s3-main form{padding:17px;background:#f3f3f3;border-radius:9px;margin:47px;border:none}#s3-main form span{color:red}#s3-main form label{display:block;background:azure;border:2px dashed #03a9f4;position:relative;margin:20px 0}#s3-main form label input{height:180px;width:100%;opacity:0;cursor:grab}#s3-main form label b{position:absolute;top:40%;left:42%;display:flex;font-size:20px}#s3-main form form:invalid #upload{background-color:#aaa;pointer-events:none}#s3-main progress{width:100%;margin-top:15px}\n"] }]
        }], ctorParameters: function () { return [{ type: TriggerDirective }, { type: i2.HttpClient }, { type: i0.ChangeDetectorRef }]; } });

class TriggerDirective {
    openModal() {
        this.vc.createComponent(ImageManagerComponent, { injector: this.injector });
    }
    constructor(vc, injector) {
        this.vc = vc;
        this.injector = injector;
        this.apiPaths = { getImages: '/', upload: '/upload', delete: '/delete' };
        this.disableDelete = false;
        this.s3imgSelected = new EventEmitter();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.0.2", ngImport: i0, type: TriggerDirective, deps: [{ token: i0.ViewContainerRef }, { token: i0.Injector }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.0.2", type: TriggerDirective, selector: "[s3imgsTrigger]", inputs: { apiPaths: ["s3imgsTrigger", "apiPaths"], disableDelete: "disableDelete" }, outputs: { s3imgSelected: "s3imgSelected" }, host: { listeners: { "click": "openModal()" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.0.2", ngImport: i0, type: TriggerDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[s3imgsTrigger]'
                }]
        }], ctorParameters: function () { return [{ type: i0.ViewContainerRef }, { type: i0.Injector }]; }, propDecorators: { apiPaths: [{
                type: Input,
                args: ['s3imgsTrigger']
            }], disableDelete: [{
                type: Input
            }], s3imgSelected: [{
                type: Output
            }], openModal: [{
                type: HostListener,
                args: ['click']
            }] } });

class AngularAWSPrivateImageManagerModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.0.2", ngImport: i0, type: AngularAWSPrivateImageManagerModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.0.2", ngImport: i0, type: AngularAWSPrivateImageManagerModule, declarations: [TriggerDirective,
            ImageManagerComponent], imports: [CommonModule, HttpClientModule], exports: [TriggerDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.0.2", ngImport: i0, type: AngularAWSPrivateImageManagerModule, imports: [CommonModule, HttpClientModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.0.2", ngImport: i0, type: AngularAWSPrivateImageManagerModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        TriggerDirective,
                        ImageManagerComponent
                    ],
                    imports: [CommonModule, HttpClientModule],
                    exports: [TriggerDirective]
                }]
        }] });

/*
 * Public API Surface of ngx-aws-s3-private-image-mng
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AngularAWSPrivateImageManagerModule, TriggerDirective };
//# sourceMappingURL=ngx-aws-s3-private-image-mng.mjs.map
